@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12785 2021-02-25 16:33:33Z Lavender $
+# $Id: __init__.py 13360 2021-11-25 10:09:45Z Tiffany $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2021-02-26 00:33:33 +0800 (Fri, 26 Feb 2021) $
-# $Revision: 12785 $
+# $Author: Tiffany $ (last)
+# $Date: 2021-11-25 18:09:45 +0800 (Thu, 25 Nov 2021) $
+# $Revision: 13360 $
 
 import os
 import re
@@ -175,7 +175,7 @@ def attachSettings(settingsDict, enablePaypal=False):
                     if pattern.startswith(override):
                         if 'reviews' in pattern and not 'reviews' in override:
                             continue
-                        if 'dashboard' in override and 'dashboard' not in pattern:
+                        if 'dashboard' in override and 'dashboard' != pattern:
                             continue
                         return override
                 return app_label
@@ -536,7 +536,8 @@ def attachSettings(settingsDict, enablePaypal=False):
     if not hasConfig:
         
         languageCode = settingsDict.get('LANGUAGE_CODE', 'en') 
-        if (languageCode == 'zh-hant') or (languageCode == 'zh') or (languageCode == 'zh-hans'):
+        if (languageCode == 'zh-hant') or (languageCode == 'zh') or (languageCode == 'zh-hans') or \
+            (languageCode == 'zh-tw'):
             if needShipping:
                 ADDING_OSCAR_ORDER_STATUS = {
                     'OSCAR_PROCESSING_SEND_EMAIL_STATUS': u'商品送貨中',
