@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 13327 2021-09-13 07:00:54Z Becca $
+# $Id: forms.py 13328 2021-09-13 07:12:34Z Becca $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Becca $ (last)
-# $Date: 2021-09-13 15:00:54 +0800 (Mon, 13 Sep 2021) $
-# $Revision: 13327 $
+# $Date: 2021-09-13 15:12:34 +0800 (Mon, 13 Sep 2021) $
+# $Revision: 13328 $
 
 import os
 import re
@@ -342,7 +342,7 @@ class ShippingAddressForm2(ShippingAddressForm1):
         
         fields = [
             'ordererFirstName', 'ordererLastName', 'ordererLine1', 
-            'ordererLine4', 'ordererCountry', 'ordererPostcode',
+            'ordererLine4', 'ordererCountry', 'ordererPostcode', 'ordererPhone'
         ] + ShippingAddressForm1.Meta.fields
   
     def clean_odererPostcode(self):
